@@ -7,6 +7,4 @@ from .data_structures import (
     IdefixVtkHierarchy,
     PlutoVtkDataset,
 )
-from .fields import IdefixDmpFieldInfo, IdefixVtkFieldInfo
-from .io import IdefixDmpIOHandler, IdefixVtkIOHandler
 from .loaders import load, load_stretched
