@@ -4,7 +4,6 @@ import warnings
 
 import numpy as np
 
-import yt
 from yt_idefix._io import vtk_io
 from yt_idefix.data_structures import IdefixVtkDataset, PlutoVtkDataset
 
@@ -16,14 +15,17 @@ class VisibleDeprecationWarning(Warning):
 
 
 def load(fn, *args, **kwargs):
+    import yt
+
     warnings.warn(
-        "yt_idefix.load is now a strict alias to yt.load, "
-        "please use yt.load directly. "
+        "yt_idefix.load is a diminished wrapper for to yt.load, "
+        "please use yt.load instead.\n"
         "yt_idefix.load was deprecated in version 0.11.0 "
-        "and will be removed no later than version 0.13.0",
+        "and will be removed completely in a future version",
         category=VisibleDeprecationWarning,
         stacklevel=2,
     )
+
     return yt.load(fn, *args, **kwargs)
 
 
@@ -36,6 +38,15 @@ def load_stretched(fn, *, geometry: str | None = None, **kwargs):
     - no lazy-loading (all data has to reside in memory)
     - only supports vtk outputs (not dumps)
     """
+    import yt
+
+    warnings.warn(
+        "yt_idefix.load_strecthed is deprecated "
+        "and will be removed completely in a future version. "
+        "Please use yt.load instead.",
+        category=VisibleDeprecationWarning,
+        stacklevel=2,
+    )
 
     # brute force validation
     if not (
@@ -78,7 +89,7 @@ def load_stretched(fn, *, geometry: str | None = None, **kwargs):
         ]
     )
 
-    return yt.load_hexahedral_mesh(
+    ds = yt.load_hexahedral_mesh(
         data,
         coordinates=coordinates,
         connectivity=connectivity,
@@ -86,3 +97,9 @@ def load_stretched(fn, *, geometry: str | None = None, **kwargs):
         geometry=geometry,
         **kwargs,
     )
+    try:
+        ds.current_time = md["time"] * ds.time_unit
+    except KeyError:
+        # old Idefix vtk and Pluto vtks don't contain a "time" field
+        pass
+    return ds
